@@ -1,12 +1,9 @@
 import xarray as xr
 import numpy as np
 import pytest
-from astropy.convolution import (
-    convolve_fft,
-    Gaussian1DKernel,
-    Gaussian2DKernel,
-)
 
+astropy = pytest.importorskip("astropy")
+from astropy.convolution import convolve_fft, Gaussian1DKernel, Gaussian2DKernel
 from xarrayutils.filtering import filter_1D, filter_2D
 
 
